@@ -130,11 +130,20 @@
  *   Add variable bit length output.
  *
  */
+
+#ifdef _MSC_VER
+#	define	WINDOWS
+#endif
+
+#ifdef __MINGW32__
+#	define	DIRENT
+#	define	MINGW
+#endif
+
 #include	<stdint.h>
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<string.h>
-#include	<unistd.h>
 #include	<fcntl.h>
 #include	<ctype.h>
 #include	<signal.h>
@@ -142,6 +151,10 @@
 #include	<sys/stat.h>
 #include	<errno.h>
 
+#if !defined(DOS) && !defined(WINDOWS)
+#	include	<unistd.h>
+#endif
+
 #ifdef DIRENT
 #	include	<dirent.h>
 #	define	RECURSIVE		1
@@ -166,37 +179,38 @@
 #	define	ARGS(a)				()
 #endif
 
-#define	LARGS(a)	()	/* Relay on include files for libary func defs. */
-
 #ifndef SIG_TYPE
 #	define	SIG_TYPE	void (*)()
 #endif
 
-#ifndef NOFUNCDEF
-	extern	void	*malloc	LARGS((int));
-	extern	void	free	LARGS((void *));
-#ifndef _IBMR2
-	extern	int		open	LARGS((char const *,int,...));
+#if defined(AMIGA) || defined(DOS) || defined(MINGW) || defined(WINDOWS)
+#	define	chmod(pathname, mode) 0
+#	define	chown(pathname, owner, group) 0
+#	define	utime(pathname, times) 0
 #endif
-	extern	int		close	LARGS((int));
-	extern	int		read	LARGS((int,void *,int));
-	extern	int		write	LARGS((int,void const *,int));
-	extern	int		chmod	LARGS((char const *,int));
-	extern	int		unlink	LARGS((char const *));
-	extern	int		chown	LARGS((char const *,int,int));
-	extern	int		utime	LARGS((char const *,struct utimbuf const *));
-	extern	char	*strcpy	LARGS((char *,char const *));
-	extern	char	*strcat	LARGS((char *,char const *));
-	extern	int		strcmp	LARGS((char const *,char const *));
-	extern	unsigned strlen	LARGS((char const *));
-	extern	void	*memset	LARGS((void *,char,unsigned int));
-	extern	void	*memcpy	LARGS((void *,void const *,unsigned int));
-	extern	int		atoi	LARGS((char const *));
-	extern	void	exit	LARGS((int));
-	extern	int		isatty	LARGS((int));
+
+#if defined(WINDOWS)
+#	define isatty(fd) 0
+#	define open _open
+#	define close _close
+#	define read _read
+#	define strdup _strdup
+#	define unlink _unlink
+#	define write _write
+#endif
+
+#ifndef	LSTAT
+#	define	lstat	stat
+#endif
+
+#if defined(DOS) || defined(WINDOWS)
+#	define	F_OK	0
+static inline access(const char *pathname, int mode)
+{
+	struct stat st;
+	return lstat(pathname, &st) == 0;
+}
 #endif
-	
-#define	MARK(a)	{ asm(" .globl M.a"); asm("M.a:"); }
 
 #ifdef	DEF_ERRNO
 	extern int	errno;
@@ -214,8 +228,6 @@
 #	define	OBUFSIZ	BUFSIZ	/* Default output buffer size							*/
 #endif
 
-#define	SIZE_INNER_LOOP		256	/* Size of the inter (fast) compress loop			*/
-
 							/* Defines for third byte of header 					*/
 #define	MAGIC_1		(char_type)'\037'/* First byte of compressed file				*/
 #define	MAGIC_2		(char_type)'\235'/* Second byte of compressed file				*/
@@ -920,11 +932,7 @@ comprexx(fileptr)
 		has_z_suffix = (namesize >= 2 && strcmp(&tempname[namesize - 2], ".Z") == 0);
 		errno = 0;
 
-#ifdef	LSTAT
 		if (lstat(tempname,&infstat) == -1)
-#else
-		if (stat(tempname,&infstat) == -1)
-#endif
 		{
 		  	if (do_decomp)
 			{
@@ -942,11 +950,7 @@ comprexx(fileptr)
 						namesize += 2;
 						has_z_suffix = 1;
 						errno = 0;
-#ifdef	LSTAT
 						if (lstat(tempname,&infstat) == -1)
-#else
-						if (stat(tempname,&infstat) == -1)
-#endif
 						{
 						  	perror(tempname);
 							goto error;
@@ -1137,7 +1141,6 @@ comprexx(fileptr)
 					{
 						fprintf(stderr, "\nunlink error (ignored) ");
 	    				perror(ofname);
-						exit_code = 1;
 					}
 		
 					remove_ofname = 0;
@@ -1185,32 +1188,26 @@ comprexx(fileptr)
 					{
 						fprintf(stderr, "\nutime error (ignored) ");
 				    	perror(ofname);
-						exit_code = 1;
 					}
 
-#ifndef	AMIGA
 					if (chmod(ofname, infstat.st_mode & 07777))		/* Copy modes */
 					{
 						fprintf(stderr, "\nchmod error (ignored) ");
 				    	perror(ofname);
-						exit_code = 1;
 					}
-#ifndef	DOS
+
 					if (chown(ofname, infstat.st_uid, infstat.st_gid))	/* Copy ownership */
 					{
 						fprintf(stderr, "\nchown error (ignored) ");
 						perror(ofname);
-						exit_code = 1;
 					}
-#endif
-#endif
+
 					remove_ofname = 0;
 
 					if (unlink(ifname))	/* Remove input file */
 					{
 						fprintf(stderr, "\nunlink error (ignored) ");
 	    				perror(ifname);
-						exit_code = 1;
 					}
     			}
     		}
